pub struct OwnedReader { /* private fields */ }Available on crate feature
v3 only.Expand description
A reader for owned data that is already in memory.
Implementations
Sourceimpl OwnedReader
impl OwnedReader
pub fn parse(webc: impl Into<OwnedBuffer>) -> Result<Self, OwnedReaderError>
pub fn from_path(path: impl AsRef<Path>) -> Result<Self, OwnedReaderError>
Sourcepub fn from_file(file: File) -> Result<Self, OwnedReaderError>
pub fn from_file(file: File) -> Result<Self, OwnedReaderError>
Try to parse a File into an OwnedReader.
This will try to memory-map the file if supported by the OS, otherwise it will read the entire file into memory.
pub fn webc_hash(&self) -> Option<[u8; 32]>
pub fn manifest(&self) -> &Manifest
pub fn index(&self) -> &Index
pub fn atoms_hash(&self) -> [u8; 32]
pub fn atom_names(&self) -> impl Iterator<Item = &str> + '_
pub fn iter_atoms( &self, ) -> impl Iterator<Item = (&str, [u8; 32], &OwnedBuffer)> + '_
pub fn get_atom(&self, name: &str) -> Option<&([u8; 32], OwnedBuffer)>
pub fn volume_names(&self) -> impl Iterator<Item = &str> + '_
pub fn iter_volumes( &self, ) -> impl Iterator<Item = Result<(&str, VolumeSection), OwnedReaderError>>
pub fn get_volume(&self, name: &str) -> Result<VolumeSection, OwnedReaderError>